# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetCatalogResult:
    """
    A collection of values returned by getCatalog.
    """
    def __init__(__self__, annotations=None, branch=None, cluster_id=None, description=None, id=None, kind=None, labels=None, name=None, password=None, project_id=None, scope=None, url=None, username=None, version=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for the catalog (map)
        """
        if branch and not isinstance(branch, str):
            raise TypeError("Expected argument 'branch' to be a str")
        __self__.branch = branch
        """
        (Computed) The branch of the catalog repo to use (string)
        """
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        """
        (Computed) The cluster id of the catalog (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) A catalog description (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        __self__.kind = kind
        """
        (Computed) The kind of the catalog. Just helm by the moment (string)
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for the catalog (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        __self__.password = password
        """
        (Computed/Sensitive) The password to access the catalog if needed (string)
        """
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        """
        (Computed) The project id of the catalog (string)
        """
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        __self__.scope = scope
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        __self__.url = url
        """
        (Computed) The url of the catalog repo (string)
        """
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        __self__.username = username
        """
        (Computed/Sensitive) The username to access the catalog if needed (string)
        """
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        __self__.version = version
        """
        (Computed) Helm version for the catalog (string)
        """
class AwaitableGetCatalogResult(GetCatalogResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogResult(
            annotations=self.annotations,
            branch=self.branch,
            cluster_id=self.cluster_id,
            description=self.description,
            id=self.id,
            kind=self.kind,
            labels=self.labels,
            name=self.name,
            password=self.password,
            project_id=self.project_id,
            scope=self.scope,
            url=self.url,
            username=self.username,
            version=self.version)

def get_catalog(name=None,scope=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 catalog.




    :param str name: The catalog name.
    :param str scope: The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['scope'] = scope
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCatalog:getCatalog', __args__, opts=opts).value

    return AwaitableGetCatalogResult(
        annotations=__ret__.get('annotations'),
        branch=__ret__.get('branch'),
        cluster_id=__ret__.get('clusterId'),
        description=__ret__.get('description'),
        id=__ret__.get('id'),
        kind=__ret__.get('kind'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        password=__ret__.get('password'),
        project_id=__ret__.get('projectId'),
        scope=__ret__.get('scope'),
        url=__ret__.get('url'),
        username=__ret__.get('username'),
        version=__ret__.get('version'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('rancher2')

access_key = __config__.get('accessKey') or utilities.get_env('RANCHER_ACCESS_KEY')
"""
API Key used to authenticate with the rancher server
"""

api_url = __config__.get('apiUrl') or utilities.get_env('RANCHER_URL')
"""
The URL to the rancher API
"""

bootstrap = __config__.get('bootstrap') or (utilities.get_env_bool('RANCHER_BOOTSTRAP') or False)
"""
Bootstrap rancher server
"""

ca_certs = __config__.get('caCerts') or utilities.get_env('RANCHER_CA_CERTS')
"""
CA certificates used to sign rancher server tls certificates. Mandatory if self signed tls and insecure option false
"""

insecure = __config__.get('insecure') or (utilities.get_env_bool('RANCHER_INSECURE') or False)
"""
Allow insecure connections to Rancher. Mandatory if self signed tls and not ca_certs provided
"""

retries = __config__.get('retries')
"""
Rancher connection retries
"""

secret_key = __config__.get('secretKey') or utilities.get_env('RANCHER_SECRET_KEY')
"""
API secret used to authenticate with the rancher server
"""

token_key = __config__.get('tokenKey') or utilities.get_env('RANCHER_TOKEN_KEY')
"""
API token used to authenticate with the rancher server
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterLogging(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Cluster Logging object (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id to configure logging (string)
    """
    custom_target_config: pulumi.Output[dict]
    """
    The custom target config for Cluster Logging. For `kind = custom`. Conflicts with `elasticsearch_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)

      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `clientCert` (`str`) - SSL client certificate for the syslog service (string)
      * `clientKey` (`str`) - SSL client key for the syslog service (string)
      * `content` (`str`) - Custom target config content (string)
    """
    elasticsearch_config: pulumi.Output[dict]
    """
    The elasticsearch config for Cluster Logging. For `kind = elasticsearch`. Conflicts with `custom_target_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)

      * `authPassword` (`str`) - User password for the elascticsearch service (string)
      * `authUsername` (`str`) - Username for the elascticsearch service (string)
      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `clientCert` (`str`) - SSL client certificate for the syslog service (string)
      * `clientKey` (`str`) - SSL client key for the syslog service (string)
      * `clientKeyPass` (`str`) - SSL client key password for the splunk service (string)
      * `dateFormat` (`str`) - Date format for the elascticsearch logs. Default: `YYYY-MM-DD` (string)
      * `endpoint` (`str`) - Endpoint of the syslog service (string)
      * `indexPrefix` (`str`) - Index prefix for the elascticsearch logs. Default: `local` (string)
      * `sslVerify` (`bool`) - SSL verify for the syslog service (bool)
      * `sslVersion` (`str`) - SSL version for the elascticsearch service (string)
    """
    enable_json_parsing: pulumi.Output[bool]
    """
    Enable json log parsing. Default: `false` (bool)
    """
    fluentd_config: pulumi.Output[dict]
    """
    The fluentd config for Cluster Logging. For `kind = fluentd`. Conflicts with `custom_target_config`, `elasticsearch_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)

      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `compress` (`bool`) - Compress data for the fluentd service (bool)
      * `enableTls` (`bool`) - Enable TLS for the fluentd service (bool)
      * `fluentServers` (`list`) - Servers for the fluentd service (list)
        * `endpoint` (`str`) - Endpoint of the syslog service (string)
        * `hostname` (`str`) - Hostname of the fluentd service (string)
        * `password` (`str`) - User password of the fluentd service (string)
        * `sharedKey` (`str`) - Shared key of the fluentd service (string)
        * `standby` (`bool`) - Standby server of the fluentd service (bool)
        * `username` (`str`) - Username of the fluentd service (string)
        * `weight` (`float`) - Weight of the fluentd server (int)
    """
    kafka_config: pulumi.Output[dict]
    """
    The kafka config for Cluster Logging. For `kind = kafka`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `splunk_config` and `syslog_config` (list maxitems:1)

      * `brokerEndpoints` (`list`) - Kafka endpoints for kafka service. Conflicts with `zookeeper_endpoint` (list)
      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `clientCert` (`str`) - SSL client certificate for the syslog service (string)
      * `clientKey` (`str`) - SSL client key for the syslog service (string)
      * `topic` (`str`) - Topic to publish on the kafka service (string)
      * `zookeeperEndpoint` (`str`) - Zookeeper endpoint for kafka service. Conflicts with `broker_endpoints` (string)
    """
    kind: pulumi.Output[str]
    """
    The kind of the Cluster Logging. `elasticsearch`, `fluentd`, `kafka`, `splunk` and `syslog` are supported (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Cluster Logging object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the cluster logging config (string)
    """
    namespace_id: pulumi.Output[str]
    """
    The namespace id from cluster logging (string)
    """
    output_flush_interval: pulumi.Output[float]
    """
    How often buffered logs would be flushed. Default: `3` seconds (int)
    """
    output_tags: pulumi.Output[dict]
    """
    The output tags for Cluster Logging (map)
    """
    splunk_config: pulumi.Output[dict]
    """
    The splunk config for Cluster Logging. For `kind = splunk`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `syslog_config` (list maxitems:1)

      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `clientCert` (`str`) - SSL client certificate for the syslog service (string)
      * `clientKey` (`str`) - SSL client key for the syslog service (string)
      * `clientKeyPass` (`str`) - SSL client key password for the splunk service (string)
      * `endpoint` (`str`) - Endpoint of the syslog service (string)
      * `index` (`str`) - Index prefix for the splunk logs (string)
      * `source` (`str`) - Date format for the splunk logs (string)
      * `sslVerify` (`bool`) - SSL verify for the syslog service (bool)
      * `token` (`str`) - Token for the syslog service (string)
    """
    syslog_config: pulumi.Output[dict]
    """
    The syslog config for Cluster Logging. For `kind = syslog`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `splunk_config` (list maxitems:1)

      * `certificate` (`str`) - SSL certificate for the syslog service (string)
      * `clientCert` (`str`) - SSL client certificate for the syslog service (string)
      * `clientKey` (`str`) - SSL client key for the syslog service (string)
      * `endpoint` (`str`) - Endpoint of the syslog service (string)
      * `program` (`str`) - Program for the syslog service (string)
      * `protocol` (`str`) - Protocol for the syslog service. `tcp` and `udp` are supported. Default: `udp` (string)
      * `severity` (`str`) - Date format for the syslog logs. `emergency`, `alert`, `critical`, `error`, `warning`, `notice`, `info` and `debug` are supported. Default: `notice` (string)
      * `sslVerify` (`bool`) - SSL verify for the syslog service (bool)
      * `token` (`str`) - Token for the syslog service (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, custom_target_config=None, elasticsearch_config=None, enable_json_parsing=None, fluentd_config=None, kafka_config=None, kind=None, labels=None, name=None, namespace_id=None, output_flush_interval=None, output_tags=None, splunk_config=None, syslog_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cluster Logging resource. This can be used to configure Cluster Logging for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Cluster Logging object (map)
        :param pulumi.Input[str] cluster_id: The cluster id to configure logging (string)
        :param pulumi.Input[dict] custom_target_config: The custom target config for Cluster Logging. For `kind = custom`. Conflicts with `elasticsearch_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] elasticsearch_config: The elasticsearch config for Cluster Logging. For `kind = elasticsearch`. Conflicts with `custom_target_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[bool] enable_json_parsing: Enable json log parsing. Default: `false` (bool)
        :param pulumi.Input[dict] fluentd_config: The fluentd config for Cluster Logging. For `kind = fluentd`. Conflicts with `custom_target_config`, `elasticsearch_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] kafka_config: The kafka config for Cluster Logging. For `kind = kafka`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[str] kind: The kind of the Cluster Logging. `elasticsearch`, `fluentd`, `kafka`, `splunk` and `syslog` are supported (string)
        :param pulumi.Input[dict] labels: Labels for Cluster Logging object (map)
        :param pulumi.Input[str] name: The name of the cluster logging config (string)
        :param pulumi.Input[str] namespace_id: The namespace id from cluster logging (string)
        :param pulumi.Input[float] output_flush_interval: How often buffered logs would be flushed. Default: `3` seconds (int)
        :param pulumi.Input[dict] output_tags: The output tags for Cluster Logging (map)
        :param pulumi.Input[dict] splunk_config: The splunk config for Cluster Logging. For `kind = splunk`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] syslog_config: The syslog config for Cluster Logging. For `kind = syslog`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `splunk_config` (list maxitems:1)

        The **custom_target_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `content` (`pulumi.Input[str]`) - Custom target config content (string)

        The **elasticsearch_config** object supports the following:

          * `authPassword` (`pulumi.Input[str]`) - User password for the elascticsearch service (string)
          * `authUsername` (`pulumi.Input[str]`) - Username for the elascticsearch service (string)
          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `clientKeyPass` (`pulumi.Input[str]`) - SSL client key password for the splunk service (string)
          * `dateFormat` (`pulumi.Input[str]`) - Date format for the elascticsearch logs. Default: `YYYY-MM-DD` (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `indexPrefix` (`pulumi.Input[str]`) - Index prefix for the elascticsearch logs. Default: `local` (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `sslVersion` (`pulumi.Input[str]`) - SSL version for the elascticsearch service (string)

        The **fluentd_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `compress` (`pulumi.Input[bool]`) - Compress data for the fluentd service (bool)
          * `enableTls` (`pulumi.Input[bool]`) - Enable TLS for the fluentd service (bool)
          * `fluentServers` (`pulumi.Input[list]`) - Servers for the fluentd service (list)
            * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
            * `hostname` (`pulumi.Input[str]`) - Hostname of the fluentd service (string)
            * `password` (`pulumi.Input[str]`) - User password of the fluentd service (string)
            * `sharedKey` (`pulumi.Input[str]`) - Shared key of the fluentd service (string)
            * `standby` (`pulumi.Input[bool]`) - Standby server of the fluentd service (bool)
            * `username` (`pulumi.Input[str]`) - Username of the fluentd service (string)
            * `weight` (`pulumi.Input[float]`) - Weight of the fluentd server (int)

        The **kafka_config** object supports the following:

          * `brokerEndpoints` (`pulumi.Input[list]`) - Kafka endpoints for kafka service. Conflicts with `zookeeper_endpoint` (list)
          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `topic` (`pulumi.Input[str]`) - Topic to publish on the kafka service (string)
          * `zookeeperEndpoint` (`pulumi.Input[str]`) - Zookeeper endpoint for kafka service. Conflicts with `broker_endpoints` (string)

        The **splunk_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `clientKeyPass` (`pulumi.Input[str]`) - SSL client key password for the splunk service (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `index` (`pulumi.Input[str]`) - Index prefix for the splunk logs (string)
          * `source` (`pulumi.Input[str]`) - Date format for the splunk logs (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `token` (`pulumi.Input[str]`) - Token for the syslog service (string)

        The **syslog_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `program` (`pulumi.Input[str]`) - Program for the syslog service (string)
          * `protocol` (`pulumi.Input[str]`) - Protocol for the syslog service. `tcp` and `udp` are supported. Default: `udp` (string)
          * `severity` (`pulumi.Input[str]`) - Date format for the syslog logs. `emergency`, `alert`, `critical`, `error`, `warning`, `notice`, `info` and `debug` are supported. Default: `notice` (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `token` (`pulumi.Input[str]`) - Token for the syslog service (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['custom_target_config'] = custom_target_config
            __props__['elasticsearch_config'] = elasticsearch_config
            __props__['enable_json_parsing'] = enable_json_parsing
            __props__['fluentd_config'] = fluentd_config
            __props__['kafka_config'] = kafka_config
            if kind is None:
                raise TypeError("Missing required property 'kind'")
            __props__['kind'] = kind
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['namespace_id'] = namespace_id
            __props__['output_flush_interval'] = output_flush_interval
            __props__['output_tags'] = output_tags
            __props__['splunk_config'] = splunk_config
            __props__['syslog_config'] = syslog_config
        super(ClusterLogging, __self__).__init__(
            'rancher2:index/clusterLogging:ClusterLogging',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, custom_target_config=None, elasticsearch_config=None, enable_json_parsing=None, fluentd_config=None, kafka_config=None, kind=None, labels=None, name=None, namespace_id=None, output_flush_interval=None, output_tags=None, splunk_config=None, syslog_config=None):
        """
        Get an existing ClusterLogging resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Cluster Logging object (map)
        :param pulumi.Input[str] cluster_id: The cluster id to configure logging (string)
        :param pulumi.Input[dict] custom_target_config: The custom target config for Cluster Logging. For `kind = custom`. Conflicts with `elasticsearch_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] elasticsearch_config: The elasticsearch config for Cluster Logging. For `kind = elasticsearch`. Conflicts with `custom_target_config`, `fluentd_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[bool] enable_json_parsing: Enable json log parsing. Default: `false` (bool)
        :param pulumi.Input[dict] fluentd_config: The fluentd config for Cluster Logging. For `kind = fluentd`. Conflicts with `custom_target_config`, `elasticsearch_config`, `kafka_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] kafka_config: The kafka config for Cluster Logging. For `kind = kafka`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `splunk_config` and `syslog_config` (list maxitems:1)
        :param pulumi.Input[str] kind: The kind of the Cluster Logging. `elasticsearch`, `fluentd`, `kafka`, `splunk` and `syslog` are supported (string)
        :param pulumi.Input[dict] labels: Labels for Cluster Logging object (map)
        :param pulumi.Input[str] name: The name of the cluster logging config (string)
        :param pulumi.Input[str] namespace_id: The namespace id from cluster logging (string)
        :param pulumi.Input[float] output_flush_interval: How often buffered logs would be flushed. Default: `3` seconds (int)
        :param pulumi.Input[dict] output_tags: The output tags for Cluster Logging (map)
        :param pulumi.Input[dict] splunk_config: The splunk config for Cluster Logging. For `kind = splunk`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `syslog_config` (list maxitems:1)
        :param pulumi.Input[dict] syslog_config: The syslog config for Cluster Logging. For `kind = syslog`. Conflicts with `custom_target_config`, `elasticsearch_config`, `fluentd_config`, `kafka_config`, and `splunk_config` (list maxitems:1)

        The **custom_target_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `content` (`pulumi.Input[str]`) - Custom target config content (string)

        The **elasticsearch_config** object supports the following:

          * `authPassword` (`pulumi.Input[str]`) - User password for the elascticsearch service (string)
          * `authUsername` (`pulumi.Input[str]`) - Username for the elascticsearch service (string)
          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `clientKeyPass` (`pulumi.Input[str]`) - SSL client key password for the splunk service (string)
          * `dateFormat` (`pulumi.Input[str]`) - Date format for the elascticsearch logs. Default: `YYYY-MM-DD` (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `indexPrefix` (`pulumi.Input[str]`) - Index prefix for the elascticsearch logs. Default: `local` (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `sslVersion` (`pulumi.Input[str]`) - SSL version for the elascticsearch service (string)

        The **fluentd_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `compress` (`pulumi.Input[bool]`) - Compress data for the fluentd service (bool)
          * `enableTls` (`pulumi.Input[bool]`) - Enable TLS for the fluentd service (bool)
          * `fluentServers` (`pulumi.Input[list]`) - Servers for the fluentd service (list)
            * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
            * `hostname` (`pulumi.Input[str]`) - Hostname of the fluentd service (string)
            * `password` (`pulumi.Input[str]`) - User password of the fluentd service (string)
            * `sharedKey` (`pulumi.Input[str]`) - Shared key of the fluentd service (string)
            * `standby` (`pulumi.Input[bool]`) - Standby server of the fluentd service (bool)
            * `username` (`pulumi.Input[str]`) - Username of the fluentd service (string)
            * `weight` (`pulumi.Input[float]`) - Weight of the fluentd server (int)

        The **kafka_config** object supports the following:

          * `brokerEndpoints` (`pulumi.Input[list]`) - Kafka endpoints for kafka service. Conflicts with `zookeeper_endpoint` (list)
          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `topic` (`pulumi.Input[str]`) - Topic to publish on the kafka service (string)
          * `zookeeperEndpoint` (`pulumi.Input[str]`) - Zookeeper endpoint for kafka service. Conflicts with `broker_endpoints` (string)

        The **splunk_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `clientKeyPass` (`pulumi.Input[str]`) - SSL client key password for the splunk service (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `index` (`pulumi.Input[str]`) - Index prefix for the splunk logs (string)
          * `source` (`pulumi.Input[str]`) - Date format for the splunk logs (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `token` (`pulumi.Input[str]`) - Token for the syslog service (string)

        The **syslog_config** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - SSL certificate for the syslog service (string)
          * `clientCert` (`pulumi.Input[str]`) - SSL client certificate for the syslog service (string)
          * `clientKey` (`pulumi.Input[str]`) - SSL client key for the syslog service (string)
          * `endpoint` (`pulumi.Input[str]`) - Endpoint of the syslog service (string)
          * `program` (`pulumi.Input[str]`) - Program for the syslog service (string)
          * `protocol` (`pulumi.Input[str]`) - Protocol for the syslog service. `tcp` and `udp` are supported. Default: `udp` (string)
          * `severity` (`pulumi.Input[str]`) - Date format for the syslog logs. `emergency`, `alert`, `critical`, `error`, `warning`, `notice`, `info` and `debug` are supported. Default: `notice` (string)
          * `sslVerify` (`pulumi.Input[bool]`) - SSL verify for the syslog service (bool)
          * `token` (`pulumi.Input[str]`) - Token for the syslog service (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["custom_target_config"] = custom_target_config
        __props__["elasticsearch_config"] = elasticsearch_config
        __props__["enable_json_parsing"] = enable_json_parsing
        __props__["fluentd_config"] = fluentd_config
        __props__["kafka_config"] = kafka_config
        __props__["kind"] = kind
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["namespace_id"] = namespace_id
        __props__["output_flush_interval"] = output_flush_interval
        __props__["output_tags"] = output_tags
        __props__["splunk_config"] = splunk_config
        __props__["syslog_config"] = syslog_config
        return ClusterLogging(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, annotations=None, cluster_id=None, container_resource_limit=None, description=None, enable_project_monitoring=None, id=None, labels=None, name=None, pod_security_policy_template_id=None, resource_quota=None, uuid=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations of the rancher2 project (map)
        """
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        if container_resource_limit and not isinstance(container_resource_limit, dict):
            raise TypeError("Expected argument 'container_resource_limit' to be a dict")
        __self__.container_resource_limit = container_resource_limit
        """
        (Computed) Default containers resource limits on project (List maxitem:1)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) The project's description (string)
        """
        if enable_project_monitoring and not isinstance(enable_project_monitoring, bool):
            raise TypeError("Expected argument 'enable_project_monitoring' to be a bool")
        __self__.enable_project_monitoring = enable_project_monitoring
        """
        (Computed) Enable built-in project monitoring. Default `false` (bool)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels of the rancher2 project (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if pod_security_policy_template_id and not isinstance(pod_security_policy_template_id, str):
            raise TypeError("Expected argument 'pod_security_policy_template_id' to be a str")
        __self__.pod_security_policy_template_id = pod_security_policy_template_id
        """
        (Computed) Default Pod Security Policy ID for the project (string)
        """
        if resource_quota and not isinstance(resource_quota, dict):
            raise TypeError("Expected argument 'resource_quota' to be a dict")
        __self__.resource_quota = resource_quota
        """
        (Computed) Resource quota for project. Rancher v2.1.x or higher (list maxitems:1)
        """
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        __self__.uuid = uuid
        """
        (Computed) UUID of the project as stored by Rancher 2 (string)
        """
class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            annotations=self.annotations,
            cluster_id=self.cluster_id,
            container_resource_limit=self.container_resource_limit,
            description=self.description,
            enable_project_monitoring=self.enable_project_monitoring,
            id=self.id,
            labels=self.labels,
            name=self.name,
            pod_security_policy_template_id=self.pod_security_policy_template_id,
            resource_quota=self.resource_quota,
            uuid=self.uuid)

def get_project(cluster_id=None,name=None,opts=None):
    """
    Use this data source to access information about an existing resource.

    :param str cluster_id: ID of the Rancher 2 cluster (string)
    :param str name: The project name (string)
    """
    __args__ = dict()


    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getProject:getProject', __args__, opts=opts).value

    return AwaitableGetProjectResult(
        annotations=__ret__.get('annotations'),
        cluster_id=__ret__.get('clusterId'),
        container_resource_limit=__ret__.get('containerResourceLimit'),
        description=__ret__.get('description'),
        enable_project_monitoring=__ret__.get('enableProjectMonitoring'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        pod_security_policy_template_id=__ret__.get('podSecurityPolicyTemplateId'),
        resource_quota=__ret__.get('resourceQuota'),
        uuid=__ret__.get('uuid'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetNodePoolResult:
    """
    A collection of values returned by getNodePool.
    """
    def __init__(__self__, annotations=None, cluster_id=None, control_plane=None, delete_not_ready_after_secs=None, etcd=None, hostname_prefix=None, id=None, labels=None, name=None, node_taints=None, node_template_id=None, quantity=None, worker=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for Node Pool object (map)
        """
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        if control_plane and not isinstance(control_plane, bool):
            raise TypeError("Expected argument 'control_plane' to be a bool")
        __self__.control_plane = control_plane
        """
        (Computed) RKE control plane role for created nodes (bool)
        """
        if delete_not_ready_after_secs and not isinstance(delete_not_ready_after_secs, float):
            raise TypeError("Expected argument 'delete_not_ready_after_secs' to be a float")
        __self__.delete_not_ready_after_secs = delete_not_ready_after_secs
        """
        (Computed) Delete not ready node after secs. Default `0` (int)
        """
        if etcd and not isinstance(etcd, bool):
            raise TypeError("Expected argument 'etcd' to be a bool")
        __self__.etcd = etcd
        """
        (Computed) RKE etcd role for created nodes (bool)
        """
        if hostname_prefix and not isinstance(hostname_prefix, str):
            raise TypeError("Expected argument 'hostname_prefix' to be a str")
        __self__.hostname_prefix = hostname_prefix
        """
        (Computed) The prefix for created nodes of the Node Pool (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for Node Pool object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if node_taints and not isinstance(node_taints, list):
            raise TypeError("Expected argument 'node_taints' to be a list")
        __self__.node_taints = node_taints
        """
        (Computed) Node taints (List)
        """
        if node_template_id and not isinstance(node_template_id, str):
            raise TypeError("Expected argument 'node_template_id' to be a str")
        __self__.node_template_id = node_template_id
        if quantity and not isinstance(quantity, float):
            raise TypeError("Expected argument 'quantity' to be a float")
        __self__.quantity = quantity
        """
        (Computed) The number of nodes to create on Node Pool (int)
        """
        if worker and not isinstance(worker, bool):
            raise TypeError("Expected argument 'worker' to be a bool")
        __self__.worker = worker
        """
        (Computed) RKE role role for created nodes (bool)
        """
class AwaitableGetNodePoolResult(GetNodePoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodePoolResult(
            annotations=self.annotations,
            cluster_id=self.cluster_id,
            control_plane=self.control_plane,
            delete_not_ready_after_secs=self.delete_not_ready_after_secs,
            etcd=self.etcd,
            hostname_prefix=self.hostname_prefix,
            id=self.id,
            labels=self.labels,
            name=self.name,
            node_taints=self.node_taints,
            node_template_id=self.node_template_id,
            quantity=self.quantity,
            worker=self.worker)

def get_node_pool(cluster_id=None,name=None,node_template_id=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 Node Pool resource.




    :param str cluster_id: The RKE cluster id to use Node Pool (string)
    :param str name: The name of the Node Pool (string)
    :param str node_template_id: The Node Template ID to use for node creation (string)
    """
    __args__ = dict()


    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['nodeTemplateId'] = node_template_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getNodePool:getNodePool', __args__, opts=opts).value

    return AwaitableGetNodePoolResult(
        annotations=__ret__.get('annotations'),
        cluster_id=__ret__.get('clusterId'),
        control_plane=__ret__.get('controlPlane'),
        delete_not_ready_after_secs=__ret__.get('deleteNotReadyAfterSecs'),
        etcd=__ret__.get('etcd'),
        hostname_prefix=__ret__.get('hostnamePrefix'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        node_taints=__ret__.get('nodeTaints'),
        node_template_id=__ret__.get('nodeTemplateId'),
        quantity=__ret__.get('quantity'),
        worker=__ret__.get('worker'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class User(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for global role binding (map)
    """
    enabled: pulumi.Output[bool]
    labels: pulumi.Output[dict]
    """
    Labels for global role binding (map)
    """
    name: pulumi.Output[str]
    """
    The user full name (string)
    """
    password: pulumi.Output[str]
    """
    The user password (string)
    """
    principal_ids: pulumi.Output[list]
    """
    (Computed) The user principal IDs (list)
    """
    username: pulumi.Output[str]
    """
    The user username (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, enabled=None, labels=None, name=None, password=None, username=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 User resource. This can be used to create Users for Rancher v2 environments and retrieve their information.

        When a Rancher User is created, it doesn't have a global role binding. At least, `user-base` global role binding in needed in order to enable user login.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for global role binding (map)
        :param pulumi.Input[dict] labels: Labels for global role binding (map)
        :param pulumi.Input[str] name: The user full name (string)
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[str] username: The user username (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['enabled'] = enabled
            __props__['labels'] = labels
            __props__['name'] = name
            if password is None:
                raise TypeError("Missing required property 'password'")
            __props__['password'] = password
            if username is None:
                raise TypeError("Missing required property 'username'")
            __props__['username'] = username
            __props__['principal_ids'] = None
        super(User, __self__).__init__(
            'rancher2:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, enabled=None, labels=None, name=None, password=None, principal_ids=None, username=None):
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for global role binding (map)
        :param pulumi.Input[dict] labels: Labels for global role binding (map)
        :param pulumi.Input[str] name: The user full name (string)
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[list] principal_ids: (Computed) The user principal IDs (list)
        :param pulumi.Input[str] username: The user username (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["enabled"] = enabled
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["password"] = password
        __props__["principal_ids"] = principal_ids
        __props__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class RoleTempalte(pulumi.CustomResource):
    administrative: pulumi.Output[bool]
    """
    Administrative role template. Default `false` (bool)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations for role template object (map)
    """
    builtin: pulumi.Output[bool]
    """
    (Computed) Builtin role template (string)
    """
    context: pulumi.Output[str]
    """
    Role template context. `cluster` and `project` values are supported. Default: `cluster` (string)
    """
    default_role: pulumi.Output[bool]
    """
    Default role template for new created cluster or project. Default `false` (bool)
    """
    description: pulumi.Output[str]
    """
    Role template description (string)
    """
    external: pulumi.Output[bool]
    """
    External role template. Default `false` (bool)
    """
    hidden: pulumi.Output[bool]
    """
    Hidden role template. Default `false` (bool)
    """
    labels: pulumi.Output[dict]
    """
    Labels for role template object (map)
    """
    locked: pulumi.Output[bool]
    """
    Locked role template. Default `false` (bool)
    """
    name: pulumi.Output[str]
    """
    Role template name (string)
    """
    role_template_ids: pulumi.Output[list]
    """
    Inherit role template IDs (list)
    """
    rules: pulumi.Output[list]
    """
    Role template policy rules (list)

      * `apiGroups` (`list`) - Policy rule api groups (list)
      * `nonResourceUrls` (`list`) - Policy rule non resource urls (list)
      * `resourceNames` (`list`) - Policy rule resource names (list)
      * `resources` (`list`) - Policy rule resources (list)
      * `verbs` (`list`) - Policy rule verbs. `create`, `delete`, `get`, `list`, `patch`, `update`, `watch` and `*` values are supported (list)
    """
    def __init__(__self__, resource_name, opts=None, administrative=None, annotations=None, context=None, default_role=None, description=None, external=None, hidden=None, labels=None, locked=None, name=None, role_template_ids=None, rules=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Role Template resource. This can be used to create Role Template for Rancher v2 and retrieve their information. 

        `cluster` and `project` scopes are supported for role templates.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] administrative: Administrative role template. Default `false` (bool)
        :param pulumi.Input[dict] annotations: Annotations for role template object (map)
        :param pulumi.Input[str] context: Role template context. `cluster` and `project` values are supported. Default: `cluster` (string)
        :param pulumi.Input[bool] default_role: Default role template for new created cluster or project. Default `false` (bool)
        :param pulumi.Input[str] description: Role template description (string)
        :param pulumi.Input[bool] external: External role template. Default `false` (bool)
        :param pulumi.Input[bool] hidden: Hidden role template. Default `false` (bool)
        :param pulumi.Input[dict] labels: Labels for role template object (map)
        :param pulumi.Input[bool] locked: Locked role template. Default `false` (bool)
        :param pulumi.Input[str] name: Role template name (string)
        :param pulumi.Input[list] role_template_ids: Inherit role template IDs (list)
        :param pulumi.Input[list] rules: Role template policy rules (list)

        The **rules** object supports the following:

          * `apiGroups` (`pulumi.Input[list]`) - Policy rule api groups (list)
          * `nonResourceUrls` (`pulumi.Input[list]`) - Policy rule non resource urls (list)
          * `resourceNames` (`pulumi.Input[list]`) - Policy rule resource names (list)
          * `resources` (`pulumi.Input[list]`) - Policy rule resources (list)
          * `verbs` (`pulumi.Input[list]`) - Policy rule verbs. `create`, `delete`, `get`, `list`, `patch`, `update`, `watch` and `*` values are supported (list)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['administrative'] = administrative
            __props__['annotations'] = annotations
            __props__['context'] = context
            __props__['default_role'] = default_role
            __props__['description'] = description
            __props__['external'] = external
            __props__['hidden'] = hidden
            __props__['labels'] = labels
            __props__['locked'] = locked
            __props__['name'] = name
            __props__['role_template_ids'] = role_template_ids
            __props__['rules'] = rules
            __props__['builtin'] = None
        super(RoleTempalte, __self__).__init__(
            'rancher2:index/roleTempalte:RoleTempalte',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, administrative=None, annotations=None, builtin=None, context=None, default_role=None, description=None, external=None, hidden=None, labels=None, locked=None, name=None, role_template_ids=None, rules=None):
        """
        Get an existing RoleTempalte resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] administrative: Administrative role template. Default `false` (bool)
        :param pulumi.Input[dict] annotations: Annotations for role template object (map)
        :param pulumi.Input[bool] builtin: (Computed) Builtin role template (string)
        :param pulumi.Input[str] context: Role template context. `cluster` and `project` values are supported. Default: `cluster` (string)
        :param pulumi.Input[bool] default_role: Default role template for new created cluster or project. Default `false` (bool)
        :param pulumi.Input[str] description: Role template description (string)
        :param pulumi.Input[bool] external: External role template. Default `false` (bool)
        :param pulumi.Input[bool] hidden: Hidden role template. Default `false` (bool)
        :param pulumi.Input[dict] labels: Labels for role template object (map)
        :param pulumi.Input[bool] locked: Locked role template. Default `false` (bool)
        :param pulumi.Input[str] name: Role template name (string)
        :param pulumi.Input[list] role_template_ids: Inherit role template IDs (list)
        :param pulumi.Input[list] rules: Role template policy rules (list)

        The **rules** object supports the following:

          * `apiGroups` (`pulumi.Input[list]`) - Policy rule api groups (list)
          * `nonResourceUrls` (`pulumi.Input[list]`) - Policy rule non resource urls (list)
          * `resourceNames` (`pulumi.Input[list]`) - Policy rule resource names (list)
          * `resources` (`pulumi.Input[list]`) - Policy rule resources (list)
          * `verbs` (`pulumi.Input[list]`) - Policy rule verbs. `create`, `delete`, `get`, `list`, `patch`, `update`, `watch` and `*` values are supported (list)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["administrative"] = administrative
        __props__["annotations"] = annotations
        __props__["builtin"] = builtin
        __props__["context"] = context
        __props__["default_role"] = default_role
        __props__["description"] = description
        __props__["external"] = external
        __props__["hidden"] = hidden
        __props__["labels"] = labels
        __props__["locked"] = locked
        __props__["name"] = name
        __props__["role_template_ids"] = role_template_ids
        __props__["rules"] = rules
        return RoleTempalte(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class PodSecurityPolicyTemplate(pulumi.CustomResource):
    allow_privilege_escalation: pulumi.Output[bool]
    """
    = (Optional)
    """
    allowed_capabilities: pulumi.Output[list]
    """
    (list)
    """
    allowed_csi_drivers: pulumi.Output[list]
    """
    (list)

      * `name` (`str`) - The name of the PodSecurityPolicyTemplate (string)
    """
    allowed_flex_volumes: pulumi.Output[list]
    """
    (list)

      * `driver` (`str`)
    """
    allowed_host_paths: pulumi.Output[list]
    """
    (list)

      * `pathPrefix` (`str`) - (string)
      * `readOnly` (`bool`) - (string)
    """
    allowed_proc_mount_types: pulumi.Output[list]
    """
    (list)
    """
    allowed_unsafe_sysctls: pulumi.Output[list]
    """
    (list)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations for PodSecurityPolicyTemplate object (map)
    """
    default_add_capabilities: pulumi.Output[list]
    """
    (list)
    """
    default_allow_privilege_escalation: pulumi.Output[bool]
    """
    (list)
    """
    description: pulumi.Output[str]
    """
    The PodSecurityPolicyTemplate description (string)
    """
    forbidden_sysctls: pulumi.Output[list]
    """
    (list)
    """
    fs_group: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `ranges` (`list`) - (list)
        * `max` (`float`) - (int)
        * `min` (`float`) - (int)

      * `rule` (`str`) - (string)
    """
    host_ipc: pulumi.Output[bool]
    """
    (bool)
    """
    host_network: pulumi.Output[bool]
    """
    hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
    """
    host_pid: pulumi.Output[bool]
    """
    (bool)
    """
    host_ports: pulumi.Output[list]
    """
    (list)

      * `max` (`float`) - (int)
      * `min` (`float`) - (int)
    """
    labels: pulumi.Output[dict]
    """
    Labels for PodSecurityPolicyTemplate object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the PodSecurityPolicyTemplate (string)
    """
    privileged: pulumi.Output[bool]
    """
    (bool)
    """
    read_only_root_filesystem: pulumi.Output[bool]
    """
    (bool)
    """
    required_drop_capabilities: pulumi.Output[list]
    """
    (list)
    """
    run_as_group: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `ranges` (`list`) - (list)
        * `max` (`float`) - (int)
        * `min` (`float`) - (int)

      * `rule` (`str`) - (string)
    """
    run_as_user: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `ranges` (`list`) - (list)
        * `max` (`float`) - (int)
        * `min` (`float`) - (int)

      * `rule` (`str`) - (string)
    """
    runtime_class: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `allowedRuntimeClassNames` (`list`) - (list)
      * `defaultRuntimeClassName` (`str`) - (string)
    """
    se_linux: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `rule` (`str`) - (string)
      * `seLinuxOption` (`dict`) - (list maxitems:1)
        * `level` (`str`) - (string)
        * `role` (`str`) - (string)
        * `type` (`str`) - (string)
        * `user` (`str`) - (string)
    """
    supplemental_group: pulumi.Output[dict]
    """
    (list maxitems:1)

      * `ranges` (`list`) - (list)
        * `max` (`float`) - (int)
        * `min` (`float`) - (int)

      * `rule` (`str`) - (string)
    """
    volumes: pulumi.Output[list]
    """
    (list)
    """
    def __init__(__self__, resource_name, opts=None, allow_privilege_escalation=None, allowed_capabilities=None, allowed_csi_drivers=None, allowed_flex_volumes=None, allowed_host_paths=None, allowed_proc_mount_types=None, allowed_unsafe_sysctls=None, annotations=None, default_add_capabilities=None, default_allow_privilege_escalation=None, description=None, forbidden_sysctls=None, fs_group=None, host_ipc=None, host_network=None, host_pid=None, host_ports=None, labels=None, name=None, privileged=None, read_only_root_filesystem=None, required_drop_capabilities=None, run_as_group=None, run_as_user=None, runtime_class=None, se_linux=None, supplemental_group=None, volumes=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 PodSecurityPolicyTemplate resource. This can be used to create PodSecurityPolicyTemplates for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_privilege_escalation: = (Optional)
        :param pulumi.Input[list] allowed_capabilities: (list)
        :param pulumi.Input[list] allowed_csi_drivers: (list)
        :param pulumi.Input[list] allowed_flex_volumes: (list)
        :param pulumi.Input[list] allowed_host_paths: (list)
        :param pulumi.Input[list] allowed_proc_mount_types: (list)
        :param pulumi.Input[list] allowed_unsafe_sysctls: (list)
        :param pulumi.Input[dict] annotations: Annotations for PodSecurityPolicyTemplate object (map)
        :param pulumi.Input[list] default_add_capabilities: (list)
        :param pulumi.Input[bool] default_allow_privilege_escalation: (list)
        :param pulumi.Input[str] description: The PodSecurityPolicyTemplate description (string)
        :param pulumi.Input[list] forbidden_sysctls: (list)
        :param pulumi.Input[dict] fs_group: (list maxitems:1)
        :param pulumi.Input[bool] host_ipc: (bool)
        :param pulumi.Input[bool] host_network: hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
        :param pulumi.Input[bool] host_pid: (bool)
        :param pulumi.Input[list] host_ports: (list)
        :param pulumi.Input[dict] labels: Labels for PodSecurityPolicyTemplate object (map)
        :param pulumi.Input[str] name: The name of the PodSecurityPolicyTemplate (string)
        :param pulumi.Input[bool] privileged: (bool)
        :param pulumi.Input[bool] read_only_root_filesystem: (bool)
        :param pulumi.Input[list] required_drop_capabilities: (list)
        :param pulumi.Input[dict] run_as_group: (list maxitems:1)
        :param pulumi.Input[dict] run_as_user: (list maxitems:1)
        :param pulumi.Input[dict] runtime_class: (list maxitems:1)
        :param pulumi.Input[dict] se_linux: (list maxitems:1)
        :param pulumi.Input[dict] supplemental_group: (list maxitems:1)
        :param pulumi.Input[list] volumes: (list)

        The **allowed_csi_drivers** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the PodSecurityPolicyTemplate (string)

        The **allowed_flex_volumes** object supports the following:

          * `driver` (`pulumi.Input[str]`)

        The **allowed_host_paths** object supports the following:

          * `pathPrefix` (`pulumi.Input[str]`) - (string)
          * `readOnly` (`pulumi.Input[bool]`) - (string)

        The **fs_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **host_ports** object supports the following:

          * `max` (`pulumi.Input[float]`) - (int)
          * `min` (`pulumi.Input[float]`) - (int)

        The **run_as_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **run_as_user** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **runtime_class** object supports the following:

          * `allowedRuntimeClassNames` (`pulumi.Input[list]`) - (list)
          * `defaultRuntimeClassName` (`pulumi.Input[str]`) - (string)

        The **se_linux** object supports the following:

          * `rule` (`pulumi.Input[str]`) - (string)
          * `seLinuxOption` (`pulumi.Input[dict]`) - (list maxitems:1)
            * `level` (`pulumi.Input[str]`) - (string)
            * `role` (`pulumi.Input[str]`) - (string)
            * `type` (`pulumi.Input[str]`) - (string)
            * `user` (`pulumi.Input[str]`) - (string)

        The **supplemental_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['allow_privilege_escalation'] = allow_privilege_escalation
            __props__['allowed_capabilities'] = allowed_capabilities
            __props__['allowed_csi_drivers'] = allowed_csi_drivers
            __props__['allowed_flex_volumes'] = allowed_flex_volumes
            __props__['allowed_host_paths'] = allowed_host_paths
            __props__['allowed_proc_mount_types'] = allowed_proc_mount_types
            __props__['allowed_unsafe_sysctls'] = allowed_unsafe_sysctls
            __props__['annotations'] = annotations
            __props__['default_add_capabilities'] = default_add_capabilities
            __props__['default_allow_privilege_escalation'] = default_allow_privilege_escalation
            __props__['description'] = description
            __props__['forbidden_sysctls'] = forbidden_sysctls
            __props__['fs_group'] = fs_group
            __props__['host_ipc'] = host_ipc
            __props__['host_network'] = host_network
            __props__['host_pid'] = host_pid
            __props__['host_ports'] = host_ports
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['privileged'] = privileged
            __props__['read_only_root_filesystem'] = read_only_root_filesystem
            __props__['required_drop_capabilities'] = required_drop_capabilities
            __props__['run_as_group'] = run_as_group
            __props__['run_as_user'] = run_as_user
            __props__['runtime_class'] = runtime_class
            __props__['se_linux'] = se_linux
            __props__['supplemental_group'] = supplemental_group
            __props__['volumes'] = volumes
        super(PodSecurityPolicyTemplate, __self__).__init__(
            'rancher2:index/podSecurityPolicyTemplate:PodSecurityPolicyTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, allow_privilege_escalation=None, allowed_capabilities=None, allowed_csi_drivers=None, allowed_flex_volumes=None, allowed_host_paths=None, allowed_proc_mount_types=None, allowed_unsafe_sysctls=None, annotations=None, default_add_capabilities=None, default_allow_privilege_escalation=None, description=None, forbidden_sysctls=None, fs_group=None, host_ipc=None, host_network=None, host_pid=None, host_ports=None, labels=None, name=None, privileged=None, read_only_root_filesystem=None, required_drop_capabilities=None, run_as_group=None, run_as_user=None, runtime_class=None, se_linux=None, supplemental_group=None, volumes=None):
        """
        Get an existing PodSecurityPolicyTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_privilege_escalation: = (Optional)
        :param pulumi.Input[list] allowed_capabilities: (list)
        :param pulumi.Input[list] allowed_csi_drivers: (list)
        :param pulumi.Input[list] allowed_flex_volumes: (list)
        :param pulumi.Input[list] allowed_host_paths: (list)
        :param pulumi.Input[list] allowed_proc_mount_types: (list)
        :param pulumi.Input[list] allowed_unsafe_sysctls: (list)
        :param pulumi.Input[dict] annotations: Annotations for PodSecurityPolicyTemplate object (map)
        :param pulumi.Input[list] default_add_capabilities: (list)
        :param pulumi.Input[bool] default_allow_privilege_escalation: (list)
        :param pulumi.Input[str] description: The PodSecurityPolicyTemplate description (string)
        :param pulumi.Input[list] forbidden_sysctls: (list)
        :param pulumi.Input[dict] fs_group: (list maxitems:1)
        :param pulumi.Input[bool] host_ipc: (bool)
        :param pulumi.Input[bool] host_network: hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
        :param pulumi.Input[bool] host_pid: (bool)
        :param pulumi.Input[list] host_ports: (list)
        :param pulumi.Input[dict] labels: Labels for PodSecurityPolicyTemplate object (map)
        :param pulumi.Input[str] name: The name of the PodSecurityPolicyTemplate (string)
        :param pulumi.Input[bool] privileged: (bool)
        :param pulumi.Input[bool] read_only_root_filesystem: (bool)
        :param pulumi.Input[list] required_drop_capabilities: (list)
        :param pulumi.Input[dict] run_as_group: (list maxitems:1)
        :param pulumi.Input[dict] run_as_user: (list maxitems:1)
        :param pulumi.Input[dict] runtime_class: (list maxitems:1)
        :param pulumi.Input[dict] se_linux: (list maxitems:1)
        :param pulumi.Input[dict] supplemental_group: (list maxitems:1)
        :param pulumi.Input[list] volumes: (list)

        The **allowed_csi_drivers** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the PodSecurityPolicyTemplate (string)

        The **allowed_flex_volumes** object supports the following:

          * `driver` (`pulumi.Input[str]`)

        The **allowed_host_paths** object supports the following:

          * `pathPrefix` (`pulumi.Input[str]`) - (string)
          * `readOnly` (`pulumi.Input[bool]`) - (string)

        The **fs_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **host_ports** object supports the following:

          * `max` (`pulumi.Input[float]`) - (int)
          * `min` (`pulumi.Input[float]`) - (int)

        The **run_as_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **run_as_user** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)

        The **runtime_class** object supports the following:

          * `allowedRuntimeClassNames` (`pulumi.Input[list]`) - (list)
          * `defaultRuntimeClassName` (`pulumi.Input[str]`) - (string)

        The **se_linux** object supports the following:

          * `rule` (`pulumi.Input[str]`) - (string)
          * `seLinuxOption` (`pulumi.Input[dict]`) - (list maxitems:1)
            * `level` (`pulumi.Input[str]`) - (string)
            * `role` (`pulumi.Input[str]`) - (string)
            * `type` (`pulumi.Input[str]`) - (string)
            * `user` (`pulumi.Input[str]`) - (string)

        The **supplemental_group** object supports the following:

          * `ranges` (`pulumi.Input[list]`) - (list)
            * `max` (`pulumi.Input[float]`) - (int)
            * `min` (`pulumi.Input[float]`) - (int)

          * `rule` (`pulumi.Input[str]`) - (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["allow_privilege_escalation"] = allow_privilege_escalation
        __props__["allowed_capabilities"] = allowed_capabilities
        __props__["allowed_csi_drivers"] = allowed_csi_drivers
        __props__["allowed_flex_volumes"] = allowed_flex_volumes
        __props__["allowed_host_paths"] = allowed_host_paths
        __props__["allowed_proc_mount_types"] = allowed_proc_mount_types
        __props__["allowed_unsafe_sysctls"] = allowed_unsafe_sysctls
        __props__["annotations"] = annotations
        __props__["default_add_capabilities"] = default_add_capabilities
        __props__["default_allow_privilege_escalation"] = default_allow_privilege_escalation
        __props__["description"] = description
        __props__["forbidden_sysctls"] = forbidden_sysctls
        __props__["fs_group"] = fs_group
        __props__["host_ipc"] = host_ipc
        __props__["host_network"] = host_network
        __props__["host_pid"] = host_pid
        __props__["host_ports"] = host_ports
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["privileged"] = privileged
        __props__["read_only_root_filesystem"] = read_only_root_filesystem
        __props__["required_drop_capabilities"] = required_drop_capabilities
        __props__["run_as_group"] = run_as_group
        __props__["run_as_user"] = run_as_user
        __props__["runtime_class"] = runtime_class
        __props__["se_linux"] = se_linux
        __props__["supplemental_group"] = supplemental_group
        __props__["volumes"] = volumes
        return PodSecurityPolicyTemplate(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Registry(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Registry object (map)
    """
    description: pulumi.Output[str]
    """
    A registry description (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Registry object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the registry (string)
    """
    namespace_id: pulumi.Output[str]
    """
    The namespace id where to assign the namespaced registry (string)
    """
    project_id: pulumi.Output[str]
    """
    The project id where to assign the registry (string)
    """
    registries: pulumi.Output[list]
    """
    Registries data for registry (list)

      * `address` (`str`) - Address for registry.
      * `password` (`str`) - Password for the registry (string)
      * `username` (`str`) - Username for the registry (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, description=None, labels=None, name=None, namespace_id=None, project_id=None, registries=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Registry resource. This can be used to create docker registries for Rancher v2 environments and retrieve their information.

        Depending of the availability, there are 2 types of Rancher v2 docker registries:
        - Project registry: Available to all namespaces in the `project_id`
        - Namespaced regitry: Available to just `namespace_id` in the `project_id`



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Registry object (map)
        :param pulumi.Input[str] description: A registry description (string)
        :param pulumi.Input[dict] labels: Labels for Registry object (map)
        :param pulumi.Input[str] name: The name of the registry (string)
        :param pulumi.Input[str] namespace_id: The namespace id where to assign the namespaced registry (string)
        :param pulumi.Input[str] project_id: The project id where to assign the registry (string)
        :param pulumi.Input[list] registries: Registries data for registry (list)

        The **registries** object supports the following:

          * `address` (`pulumi.Input[str]`) - Address for registry.
          * `password` (`pulumi.Input[str]`) - Password for the registry (string)
          * `username` (`pulumi.Input[str]`) - Username for the registry (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['description'] = description
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['namespace_id'] = namespace_id
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            if registries is None:
                raise TypeError("Missing required property 'registries'")
            __props__['registries'] = registries
        super(Registry, __self__).__init__(
            'rancher2:index/registry:Registry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, description=None, labels=None, name=None, namespace_id=None, project_id=None, registries=None):
        """
        Get an existing Registry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Registry object (map)
        :param pulumi.Input[str] description: A registry description (string)
        :param pulumi.Input[dict] labels: Labels for Registry object (map)
        :param pulumi.Input[str] name: The name of the registry (string)
        :param pulumi.Input[str] namespace_id: The namespace id where to assign the namespaced registry (string)
        :param pulumi.Input[str] project_id: The project id where to assign the registry (string)
        :param pulumi.Input[list] registries: Registries data for registry (list)

        The **registries** object supports the following:

          * `address` (`pulumi.Input[str]`) - Address for registry.
          * `password` (`pulumi.Input[str]`) - Password for the registry (string)
          * `username` (`pulumi.Input[str]`) - Username for the registry (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["description"] = description
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["namespace_id"] = namespace_id
        __props__["project_id"] = project_id
        __props__["registries"] = registries
        return Registry(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterAlterRule(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    The cluster alert rule annotations (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id where create cluster alert rule (string)
    """
    event_rule: pulumi.Output[dict]
    """
    The cluster alert rule event rule. ConflictsWith: `"metric_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)

      * `eventType` (`str`) - Event type. Supported values : `"Warning" | "Normal"`. Default: `Warning` (string)
      * `resourceKind` (`str`) - Resource kind. Supported values : `"DaemonSet" | "Deployment" | "Node" | "Pod" | "StatefulSet"` (string)
    """
    group_id: pulumi.Output[str]
    """
    The cluster alert rule alert group ID (string)
    """
    group_interval_seconds: pulumi.Output[float]
    """
    The cluster alert rule group interval seconds. Default: `180` (int)
    """
    group_wait_seconds: pulumi.Output[float]
    """
    The cluster alert rule group wait seconds. Default: `180` (int)
    """
    inherited: pulumi.Output[bool]
    """
    The cluster alert rule inherited. Default: `true` (bool)
    """
    labels: pulumi.Output[dict]
    """
    The cluster alert rule labels (map)
    """
    metric_rule: pulumi.Output[dict]
    """
    The cluster alert rule metric rule. ConflictsWith: `"event_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)

      * `comparison` (`str`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
      * `description` (`str`) - Metric rule description (string)
      * `duration` (`str`) - Metric rule duration (string)
      * `expression` (`str`) - Metric rule expression (string)
      * `thresholdValue` (`float`) - Metric rule threshold value (float64)
    """
    name: pulumi.Output[str]
    """
    The cluster alert rule name (string)
    """
    node_rule: pulumi.Output[dict]
    """
    The cluster alert rule node rule. ConflictsWith: `"event_rule", "metric_rule", "system_service_rule"`` (list Maxitems:1)

      * `condition` (`str`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
      * `cpuThreshold` (`float`) - Node rule cpu threshold. Default: `70` (int)
      * `memThreshold` (`float`) - Node rule mem threshold. Default: `70` (int)
      * `nodeId` (`str`) - Node ID (string)
      * `selector` (`dict`) - Node rule selector (map)
    """
    repeat_interval_seconds: pulumi.Output[float]
    """
    The cluster alert rule wait seconds. Default: `3600` (int)
    """
    severity: pulumi.Output[str]
    """
    The cluster alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
    """
    system_service_rule: pulumi.Output[dict]
    """
    The cluster alert rule system service rule. ConflictsWith: `"event_rule", "metric_rule", "node_rule"`` (list Maxitems:1)

      * `condition` (`str`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, event_rule=None, group_id=None, group_interval_seconds=None, group_wait_seconds=None, inherited=None, labels=None, metric_rule=None, name=None, node_rule=None, repeat_interval_seconds=None, severity=None, system_service_rule=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cluster Alert Rule resource. This can be used to create Cluster Alert Rule for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The cluster alert rule annotations (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create cluster alert rule (string)
        :param pulumi.Input[dict] event_rule: The cluster alert rule event rule. ConflictsWith: `"metric_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] group_id: The cluster alert rule alert group ID (string)
        :param pulumi.Input[float] group_interval_seconds: The cluster alert rule group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The cluster alert rule group wait seconds. Default: `180` (int)
        :param pulumi.Input[bool] inherited: The cluster alert rule inherited. Default: `true` (bool)
        :param pulumi.Input[dict] labels: The cluster alert rule labels (map)
        :param pulumi.Input[dict] metric_rule: The cluster alert rule metric rule. ConflictsWith: `"event_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] name: The cluster alert rule name (string)
        :param pulumi.Input[dict] node_rule: The cluster alert rule node rule. ConflictsWith: `"event_rule", "metric_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[float] repeat_interval_seconds: The cluster alert rule wait seconds. Default: `3600` (int)
        :param pulumi.Input[str] severity: The cluster alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
        :param pulumi.Input[dict] system_service_rule: The cluster alert rule system service rule. ConflictsWith: `"event_rule", "metric_rule", "node_rule"`` (list Maxitems:1)

        The **event_rule** object supports the following:

          * `eventType` (`pulumi.Input[str]`) - Event type. Supported values : `"Warning" | "Normal"`. Default: `Warning` (string)
          * `resourceKind` (`pulumi.Input[str]`) - Resource kind. Supported values : `"DaemonSet" | "Deployment" | "Node" | "Pod" | "StatefulSet"` (string)

        The **metric_rule** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
          * `description` (`pulumi.Input[str]`) - Metric rule description (string)
          * `duration` (`pulumi.Input[str]`) - Metric rule duration (string)
          * `expression` (`pulumi.Input[str]`) - Metric rule expression (string)
          * `thresholdValue` (`pulumi.Input[float]`) - Metric rule threshold value (float64)

        The **node_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
          * `cpuThreshold` (`pulumi.Input[float]`) - Node rule cpu threshold. Default: `70` (int)
          * `memThreshold` (`pulumi.Input[float]`) - Node rule mem threshold. Default: `70` (int)
          * `nodeId` (`pulumi.Input[str]`) - Node ID (string)
          * `selector` (`pulumi.Input[dict]`) - Node rule selector (map)

        The **system_service_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['event_rule'] = event_rule
            if group_id is None:
                raise TypeError("Missing required property 'group_id'")
            __props__['group_id'] = group_id
            __props__['group_interval_seconds'] = group_interval_seconds
            __props__['group_wait_seconds'] = group_wait_seconds
            __props__['inherited'] = inherited
            __props__['labels'] = labels
            __props__['metric_rule'] = metric_rule
            __props__['name'] = name
            __props__['node_rule'] = node_rule
            __props__['repeat_interval_seconds'] = repeat_interval_seconds
            __props__['severity'] = severity
            __props__['system_service_rule'] = system_service_rule
        super(ClusterAlterRule, __self__).__init__(
            'rancher2:index/clusterAlterRule:ClusterAlterRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, event_rule=None, group_id=None, group_interval_seconds=None, group_wait_seconds=None, inherited=None, labels=None, metric_rule=None, name=None, node_rule=None, repeat_interval_seconds=None, severity=None, system_service_rule=None):
        """
        Get an existing ClusterAlterRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The cluster alert rule annotations (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create cluster alert rule (string)
        :param pulumi.Input[dict] event_rule: The cluster alert rule event rule. ConflictsWith: `"metric_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] group_id: The cluster alert rule alert group ID (string)
        :param pulumi.Input[float] group_interval_seconds: The cluster alert rule group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The cluster alert rule group wait seconds. Default: `180` (int)
        :param pulumi.Input[bool] inherited: The cluster alert rule inherited. Default: `true` (bool)
        :param pulumi.Input[dict] labels: The cluster alert rule labels (map)
        :param pulumi.Input[dict] metric_rule: The cluster alert rule metric rule. ConflictsWith: `"event_rule", "node_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] name: The cluster alert rule name (string)
        :param pulumi.Input[dict] node_rule: The cluster alert rule node rule. ConflictsWith: `"event_rule", "metric_rule", "system_service_rule"`` (list Maxitems:1)
        :param pulumi.Input[float] repeat_interval_seconds: The cluster alert rule wait seconds. Default: `3600` (int)
        :param pulumi.Input[str] severity: The cluster alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
        :param pulumi.Input[dict] system_service_rule: The cluster alert rule system service rule. ConflictsWith: `"event_rule", "metric_rule", "node_rule"`` (list Maxitems:1)

        The **event_rule** object supports the following:

          * `eventType` (`pulumi.Input[str]`) - Event type. Supported values : `"Warning" | "Normal"`. Default: `Warning` (string)
          * `resourceKind` (`pulumi.Input[str]`) - Resource kind. Supported values : `"DaemonSet" | "Deployment" | "Node" | "Pod" | "StatefulSet"` (string)

        The **metric_rule** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
          * `description` (`pulumi.Input[str]`) - Metric rule description (string)
          * `duration` (`pulumi.Input[str]`) - Metric rule duration (string)
          * `expression` (`pulumi.Input[str]`) - Metric rule expression (string)
          * `thresholdValue` (`pulumi.Input[float]`) - Metric rule threshold value (float64)

        The **node_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
          * `cpuThreshold` (`pulumi.Input[float]`) - Node rule cpu threshold. Default: `70` (int)
          * `memThreshold` (`pulumi.Input[float]`) - Node rule mem threshold. Default: `70` (int)
          * `nodeId` (`pulumi.Input[str]`) - Node ID (string)
          * `selector` (`pulumi.Input[dict]`) - Node rule selector (map)

        The **system_service_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - System service rule condition. Supported values : `"controller-manager" | "etcd" | "scheduler"`. Default: `scheduler` (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["event_rule"] = event_rule
        __props__["group_id"] = group_id
        __props__["group_interval_seconds"] = group_interval_seconds
        __props__["group_wait_seconds"] = group_wait_seconds
        __props__["inherited"] = inherited
        __props__["labels"] = labels
        __props__["metric_rule"] = metric_rule
        __props__["name"] = name
        __props__["node_rule"] = node_rule
        __props__["repeat_interval_seconds"] = repeat_interval_seconds
        __props__["severity"] = severity
        __props__["system_service_rule"] = system_service_rule
        return ClusterAlterRule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ProjectAlertRule(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    The project alert rule annotations (map)
    """
    group_id: pulumi.Output[str]
    """
    The project alert rule alert group ID (string)
    """
    group_interval_seconds: pulumi.Output[float]
    """
    The project alert rule group interval seconds. Default: `180` (int)
    """
    group_wait_seconds: pulumi.Output[float]
    """
    The project alert rule group wait seconds. Default: `180` (int)
    """
    inherited: pulumi.Output[bool]
    """
    The project alert rule inherited. Default: `true` (bool)
    """
    labels: pulumi.Output[dict]
    """
    The project alert rule labels (map)
    """
    metric_rule: pulumi.Output[dict]
    """
    The project alert rule metric rule. ConflictsWith: `"pod_rule", "workload_rule"`` (list Maxitems:1)

      * `comparison` (`str`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
      * `description` (`str`) - Metric rule description (string)
      * `duration` (`str`) - Metric rule duration (string)
      * `expression` (`str`) - Metric rule expression (string)
      * `thresholdValue` (`float`) - Metric rule threshold value (float64)
    """
    name: pulumi.Output[str]
    """
    The project alert rule name (string)
    """
    pod_rule: pulumi.Output[dict]
    """
    The project alert rule pod rule. ConflictsWith: `"metric_rule", "workload_rule"`` (list Maxitems:1)

      * `condition` (`str`) - Pod rule condition. Supported values : `"notrunning" | "notscheduled" | "restarts"`. Default: `notrunning` (string)
      * `podId` (`str`) - Pod ID (string)
      * `restartIntervalSeconds` (`float`) - Pod rule restart interval seconds. Default: `300` (int)
      * `restartTimes` (`float`) - Pod rule restart times. Default: `3`  (int)
    """
    project_id: pulumi.Output[str]
    """
    The project id where create project alert rule (string)
    """
    repeat_interval_seconds: pulumi.Output[float]
    """
    The project alert rule wait seconds. Default: `3600` (int)
    """
    severity: pulumi.Output[str]
    """
    The project alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
    """
    workload_rule: pulumi.Output[dict]
    """
    The project alert rule workload rule. ConflictsWith: `"metric_rule", "pod_rule"`` (list Maxitems:1)

      * `availablePercentage` (`float`) - Workload rule available percentage. Default: `70` (int)
      * `selector` (`dict`) - Workload rule selector (map)
      * `workloadId` (`str`) - Workload ID (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, group_id=None, group_interval_seconds=None, group_wait_seconds=None, inherited=None, labels=None, metric_rule=None, name=None, pod_rule=None, project_id=None, repeat_interval_seconds=None, severity=None, workload_rule=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Project Alert Rule resource. This can be used to create Project Alert Rule for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The project alert rule annotations (map)
        :param pulumi.Input[str] group_id: The project alert rule alert group ID (string)
        :param pulumi.Input[float] group_interval_seconds: The project alert rule group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The project alert rule group wait seconds. Default: `180` (int)
        :param pulumi.Input[bool] inherited: The project alert rule inherited. Default: `true` (bool)
        :param pulumi.Input[dict] labels: The project alert rule labels (map)
        :param pulumi.Input[dict] metric_rule: The project alert rule metric rule. ConflictsWith: `"pod_rule", "workload_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] name: The project alert rule name (string)
        :param pulumi.Input[dict] pod_rule: The project alert rule pod rule. ConflictsWith: `"metric_rule", "workload_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] project_id: The project id where create project alert rule (string)
        :param pulumi.Input[float] repeat_interval_seconds: The project alert rule wait seconds. Default: `3600` (int)
        :param pulumi.Input[str] severity: The project alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
        :param pulumi.Input[dict] workload_rule: The project alert rule workload rule. ConflictsWith: `"metric_rule", "pod_rule"`` (list Maxitems:1)

        The **metric_rule** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
          * `description` (`pulumi.Input[str]`) - Metric rule description (string)
          * `duration` (`pulumi.Input[str]`) - Metric rule duration (string)
          * `expression` (`pulumi.Input[str]`) - Metric rule expression (string)
          * `thresholdValue` (`pulumi.Input[float]`) - Metric rule threshold value (float64)

        The **pod_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - Pod rule condition. Supported values : `"notrunning" | "notscheduled" | "restarts"`. Default: `notrunning` (string)
          * `podId` (`pulumi.Input[str]`) - Pod ID (string)
          * `restartIntervalSeconds` (`pulumi.Input[float]`) - Pod rule restart interval seconds. Default: `300` (int)
          * `restartTimes` (`pulumi.Input[float]`) - Pod rule restart times. Default: `3`  (int)

        The **workload_rule** object supports the following:

          * `availablePercentage` (`pulumi.Input[float]`) - Workload rule available percentage. Default: `70` (int)
          * `selector` (`pulumi.Input[dict]`) - Workload rule selector (map)
          * `workloadId` (`pulumi.Input[str]`) - Workload ID (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if group_id is None:
                raise TypeError("Missing required property 'group_id'")
            __props__['group_id'] = group_id
            __props__['group_interval_seconds'] = group_interval_seconds
            __props__['group_wait_seconds'] = group_wait_seconds
            __props__['inherited'] = inherited
            __props__['labels'] = labels
            __props__['metric_rule'] = metric_rule
            __props__['name'] = name
            __props__['pod_rule'] = pod_rule
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            __props__['repeat_interval_seconds'] = repeat_interval_seconds
            __props__['severity'] = severity
            __props__['workload_rule'] = workload_rule
        super(ProjectAlertRule, __self__).__init__(
            'rancher2:index/projectAlertRule:ProjectAlertRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, group_id=None, group_interval_seconds=None, group_wait_seconds=None, inherited=None, labels=None, metric_rule=None, name=None, pod_rule=None, project_id=None, repeat_interval_seconds=None, severity=None, workload_rule=None):
        """
        Get an existing ProjectAlertRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The project alert rule annotations (map)
        :param pulumi.Input[str] group_id: The project alert rule alert group ID (string)
        :param pulumi.Input[float] group_interval_seconds: The project alert rule group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The project alert rule group wait seconds. Default: `180` (int)
        :param pulumi.Input[bool] inherited: The project alert rule inherited. Default: `true` (bool)
        :param pulumi.Input[dict] labels: The project alert rule labels (map)
        :param pulumi.Input[dict] metric_rule: The project alert rule metric rule. ConflictsWith: `"pod_rule", "workload_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] name: The project alert rule name (string)
        :param pulumi.Input[dict] pod_rule: The project alert rule pod rule. ConflictsWith: `"metric_rule", "workload_rule"`` (list Maxitems:1)
        :param pulumi.Input[str] project_id: The project id where create project alert rule (string)
        :param pulumi.Input[float] repeat_interval_seconds: The project alert rule wait seconds. Default: `3600` (int)
        :param pulumi.Input[str] severity: The project alert rule severity. Supported values : `"critical" | "info" | "warning"`. Default: `critical` (string)
        :param pulumi.Input[dict] workload_rule: The project alert rule workload rule. ConflictsWith: `"metric_rule", "pod_rule"`` (list Maxitems:1)

        The **metric_rule** object supports the following:

          * `comparison` (`pulumi.Input[str]`) - Metric rule comparison. Supported values : `"equal" | "greater-or-equal" | "greater-than" | "less-or-equal" | "less-than" | "not-equal" | "has-value"`. Default: `equal`  (string)
          * `description` (`pulumi.Input[str]`) - Metric rule description (string)
          * `duration` (`pulumi.Input[str]`) - Metric rule duration (string)
          * `expression` (`pulumi.Input[str]`) - Metric rule expression (string)
          * `thresholdValue` (`pulumi.Input[float]`) - Metric rule threshold value (float64)

        The **pod_rule** object supports the following:

          * `condition` (`pulumi.Input[str]`) - Pod rule condition. Supported values : `"notrunning" | "notscheduled" | "restarts"`. Default: `notrunning` (string)
          * `podId` (`pulumi.Input[str]`) - Pod ID (string)
          * `restartIntervalSeconds` (`pulumi.Input[float]`) - Pod rule restart interval seconds. Default: `300` (int)
          * `restartTimes` (`pulumi.Input[float]`) - Pod rule restart times. Default: `3`  (int)

        The **workload_rule** object supports the following:

          * `availablePercentage` (`pulumi.Input[float]`) - Workload rule available percentage. Default: `70` (int)
          * `selector` (`pulumi.Input[dict]`) - Workload rule selector (map)
          * `workloadId` (`pulumi.Input[str]`) - Workload ID (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["group_id"] = group_id
        __props__["group_interval_seconds"] = group_interval_seconds
        __props__["group_wait_seconds"] = group_wait_seconds
        __props__["inherited"] = inherited
        __props__["labels"] = labels
        __props__["metric_rule"] = metric_rule
        __props__["name"] = name
        __props__["pod_rule"] = pod_rule
        __props__["project_id"] = project_id
        __props__["repeat_interval_seconds"] = repeat_interval_seconds
        __props__["severity"] = severity
        __props__["workload_rule"] = workload_rule
        return ProjectAlertRule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

